@@ -1,32 +1,63 @@
 """automatic generated to zsh completion function file"""
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 __author__ = 'Hideo Hattroi <hhatto.jp@gmail.com>'
 __license__ = 'NewBSDLicense'
 
 
 def get_parser_type(parser_obj):
     """return to 'argparse' or 'optparse'"""
-    ret = parser_obj.__module__
-    return ret
+    return parser_obj.__module__
+
+
+def _escape_squarebracket(strings):
+    """escape to only squarebracket.
+
+    >>> print _escape_squarebracket("hoge")
+    hoge
+    >>> print _escape_squarebracket("[hoge")
+    \[hoge
+    >>> print _escape_squarebracket("hoge]")
+    hoge\]
+    >>> print _escape_squarebracket("[hoge]")
+    \[hoge\]
+    """
+    ret = []
+    for string in strings:
+        if string == '[' or string == ']':
+            string = '\\' + string
+        ret.append(string)
+    return "".join(ret)
 
 
 class ZshCompletionGenerator(object):
 
+    """Generator of Zsh Completion Function"""
+
     def __init__(self, commandname=None, parser=None):
         self.commandname = commandname
         self.parser = parser
         self.parser_type = get_parser_type(parser)
 
-    def _escape_squarebracket(self, strings):
-        ret = []
-        for s in strings:
-            if s == '[' or s == ']':
-                s = '\\' + s
-            ret.append(s)
-        return "".join(ret)
+    def _get_dircomp(self, opt):
+        """judged to directories and files completion, and
+        return to ':->dirfile' or ''
+        """
+        directory_comp = ":->dirfile"
+        ## version
+        if self.parser_type == 'optparse':
+            if '--version' == opt:
+                directory_comp = ""
+        else:   # argparse
+            if '-v' == opt or '--version' == opt:
+                directory_comp = ""
+        ## help
+        if '-h' == opt or '--help' == opt:
+            directory_comp = ""
+        return directory_comp
 
     def get(self):
+        """return to string of zsh completion function."""
         if self.parser_type == 'optparse':
             actions = self.parser.option_list
         elif self.parser_type == 'argparse':
@@ -37,11 +68,8 @@ class ZshCompletionGenerator(object):
         ret.append("local context state line\n")
         ret.append("_arguments -s -S \\")
         for action in actions:
-            directory_comp = "-/"   ## default setting
             if action.metavar:
-                metavar = action.metavar
-                #if "dir" in metavar.lower():
-                #    directory_comp = "-/"
+                metavar = ":%s:" % action.metavar
             else:
                 metavar = ""
             if self.parser_type == 'optparse':
@@ -50,13 +78,14 @@ class ZshCompletionGenerator(object):
             elif self.parser_type == 'argparse':
                 opts = action.option_strings
             for opt in opts:
-                tmp = "  \"%s[%s]:%s:_files %s\" \\" % (opt,
-                      self._escape_squarebracket(action.help),
+                directory_comp = self._get_dircomp(opt)
+                tmp = "  \"%s[%s]%s:%s\" \\" % (opt,
+                      _escape_squarebracket(action.help),
                       metavar, directory_comp)
                 ret.append(tmp)
-        ret.append("  \":files:->files\" \\")
+        ret.append("  \"::dirfile:_files\" \\")
         state = "case $state in\n"\
-                "(files)\n"\
+                "(dirfile)\n"\
                 "  _files -/ && return 0\n  ;;\nesac\n"
         ret.append("  && return 0")
         ret.append(state)
